/************************************************************************/
/*																		*/
/*			H S A _ W . H - Header file for HSA Window Package			*/
/*																		*/
/************************************************************************/

/************************************************************************/
/*																		*/
/*		Copyright (c) Hardwood Software Associates, 1986				*/
/*																		*/
/************************************************************************/

/*************************************************************************
 *				H S A _ W . H   E D I T   L O G 
 *
 * $Log:   D:/crt/vcs/hsa_w.h_v  $
 *	
 *	   Rev 1.14   01 Apr 1989 10:13:12   R. Evans
 *	Add exploding windows
 *	
 *	   Rev 1.13   26 Mar 1989 16:31:04   R. Evans
 *	Add window shadow capability (w_shadow)
 *	
 *	   Rev 1.12   05 Mar 1989 11:23:48   R. Evans
 *	Add w_menu2_init
 *	
 *	   Rev 1.11   04 Dec 1988  9:29:06   R. Evans
 *	Add w_menu1_set_keycheck
 *	
 *	   Rev 1.10   16 Sep 1988 21:01:40   R. Evans
 *	Add W_MENU1_NO_MOWS & W_MENU1_NO_INSTR
 *	
 *	   Rev 1.9   27 Aug 1988 19:02:08   R. Evans
 *	Add: w_up, w_up_sc, w_down, w_down_sc, w_left, w_down, w_loc, w_nl_sc
 *	
 *	   Rev 1.8   21 Aug 1988 18:31:20   R. Evans
 *	Add w_menu2_reset and w_menu2_no_reset
 *	
 *	   Rev 1.7   21 Aug 1988  9:50:16   R. Evans
 *	Add w_menu1 action constants and LAST_SELECT
 *	Make WIN a typedef
 *	Add w_menu1_clr_last, w_menu1_get_last, w_menu1_put_last
 *	
 *	   Rev 1.6   14 Aug 1988 11:56:32   R. Evans
 *	w_nl not defined
 *	
 *	   Rev 1.5   30 Apr 1988 22:09:50   R. Evans
 *	Include hsa_attr.h
 *	
 *	   Rev 1.4   22 Apr 1988 21:49:34   R. Evans
 *	Add w_menu2
 *	
 *	   Rev 1.3   13 Mar 1988  9:27:14   R. Evans
 *	Add w_clr_eol
 *	Add w_file functions
 *	
 *	   Rev 1.2   29 Nov 1987 10:28:26   R. Evans
 *	Add w_open_ns & w_center
 *	
 *	   Rev 1.1   20 Nov 1987 21:30:06   R. Evans
 *	w_close returns NULL pointer
 *	Add w_nl
 *	
 *	   Rev 1.0   11 Aug 1987 11:46:58   R. Evans
 *	Initial revision.
 *
 ************************************************************************/

#ifndef W_
#define W_

#ifndef GENERAL
#ifdef NO_EXT_KEYS
#include "stdio.h"
#define NEAR
#define FIXED_NO_ARGS
#else
#include <stdio.h>
#define NEAR near
#define FIXED_NO_ARGS pascal
#endif
#endif

#include <hsa_attr.h>

#define ROW	0
#define COL	1
#define NO_BORDER			-1					/* No border at all */
#define SINGLE_LINES		0					/* Single on all sides */
#define DOUBLE_LINES		1					/* Double on all sides */
#define SINGLE_DOUBLE_LINES	2					/* Single vertical / Double horizontal */
#define DOUBLE_SINGLE_LINES	3					/* Double vertical / Single horizontal */
#define BLANK_BORDER		4					/* Blanks as border */
#define USER_BORDER			5					/* User defined border */
#define BORDERS				USER_BORDER+1		/* Number of borders */

#define NO_SHADOW			0					/* No shadows */
#define LR_SHADOW			1					/* Lower right shadow */
#define LL_SHADOW			2					/* Lower left shadow */
#define UR_SHADOW			3					/* Upper right shadow */
#define UL_SHADOW			4					/* Upper left shadow */
#define SHADOWS				4

#define MSG_CENTER			0					/* Center border messages */
#define MSG_LEFT			1					/* Left justify border messages */
#define MSG_RIGHT			2					/* Right justify border messages */

#define W_MENU1_DISPLAY		0x0002				/* display only */
#define W_MENU1_SELECT		0x0004				/* Select an entry */
#define W_MENU1_NO_RESET	0x0008				/* Don't reset mouse */
#define W_MENU1_START		0x0010				/* Start at last selection */
#define W_MENU1_NO_MOWS		0x0020				/* Don't use mouse, even if present */
#define W_MENU1_NO_INSTR	0x0040				/* Don't display instructions */

#define W_FLAGS_EXPLODE		0x01				/* Exploding window flag */

typedef struct									/* Last entry selected */
	{
	int page;
	int row,col;
	} LAST_SELECT;

typedef struct									/* Block of screen for window */
	{
	int row,col;								/* Upper left corner coords */
	int height,width;							/* Size of block */
	} WINDOW_BLOCK;

typedef struct									/* Window data definiion */
	{
	int	coords[2];								/* Upper left corner of inside of window */
	int size[2];								/* Size of inside of window */
	int cursor[2];								/* Current cursor offset in window */
												/* 0 based, relative to window start */
	char border_attr;							/* Attribute to be used in border */
	char shadow;								/* Shadow type */
	char attr;									/* Attribute to be used within window */
	char shadow_height;							/* Height of shadow */
	int *save;									/* Pointer to screen save buffer */
	int old[2];									/* Cursor position when window opened */
	char border;								/* Border line type */
	unsigned char flags;						/* Miscellaneous flags */
	int top_msg_pos;							/* Top message position */
	int bot_msg_pos;							/* Bottom message position */
	int col_width;								/* Column display width (plus 1, 0 if none) */
	char *top_msg;								/* Message for top border line */
	char *bot_msg;								/* Pointer to bottom border line message */
	} WIN;

												/* W_BORDER.C */
void FIXED_NO_ARGS w_user_border (char,char,char,char,char,char,char,char,char,char);
void FIXED_NO_ARGS w_border (WIN *);
void FIXED_NO_ARGS w_top_msg (WIN *, char *, int);
void FIXED_NO_ARGS w_bot_msg (WIN *, char *, int);
												/* W_CENTER.C */
int FIXED_NO_ARGS w_center (WIN *,int,char *);
int FIXED_NO_ARGS w_center_a (WIN *,int,char *,int);
												/* W_CLOSE.C */
WIN * FIXED_NO_ARGS w_close(WIN  *);
void FIXED_NO_ARGS w_restore_screen(WIN  *, int *);
												/* W_CLR.C */
void FIXED_NO_ARGS w_clr(WIN  *);
void FIXED_NO_ARGS w_clr_eol(WIN  *);
												/* W_CUR.C */
void FIXED_NO_ARGS w_up (WIN *);
int  FIXED_NO_ARGS w_up_sc (WIN *);
void FIXED_NO_ARGS w_down (WIN *);
int  FIXED_NO_ARGS w_down_sc (WIN *);
void FIXED_NO_ARGS w_left (WIN *);
void FIXED_NO_ARGS w_right (WIN *);
void FIXED_NO_ARGS w_loc (WIN *, int, int);
void FIXED_NO_ARGS w_cur_loc (WIN *);
void FIXED_NO_ARGS w_nl (WIN *);
int  FIXED_NO_ARGS w_nl_sc (WIN *);
												/* W_FILE.C */
int FIXED_NO_ARGS w_file_name (char *,int,int,int,int,int,int,int,char *);
int FIXED_NO_ARGS w_file_ptr  (FILE *,int,int,int,int,int,int,int,char *);
												/* W_MENU1.C */
int FIXED_NO_ARGS w_menu1_open(int ,int ,int ,int ,int ,int ,int ,int, char *,char *, int);
int FIXED_NO_ARGS w_menu1_fill(char *,char *);
void w_menu1_clr_last (void);
void FIXED_NO_ARGS w_menu1_get_last (LAST_SELECT *);
void FIXED_NO_ARGS w_menu1_put_last (LAST_SELECT *);
void FIXED_NO_ARGS w_menu1_set_keycheck (char (*)());
												/* W_MENU2.C */
int FIXED_NO_ARGS w_menu2 (int,int,int,int,int,char *,int,char **,char **,int);
void w_menu2_no_reset (void);
void w_menu2_reset (void);
void w_menu2_init (int);
												/* W_MOVE.C */
void FIXED_NO_ARGS w_move (WIN *, int, int);
												/* W_OPEN.C */
WIN * FIXED_NO_ARGS w_open(int ,int ,int ,int ,int ,int, int, int );
WIN * FIXED_NO_ARGS w_open_ns(int ,int ,int ,int ,int ,int, int, int );
void w_shadow (int,int);
void w_set_explode (void);
void w_clr_explode (void);
void FIXED_NO_ARGS w_window_block (WIN *,WINDOW_BLOCK *,int);
												/* W_SCROLL.C */
void FIXED_NO_ARGS w_scdn(WIN  *);
void FIXED_NO_ARGS w_scup(WIN  *);
												/* W_STR.C */
int FIXED_NO_ARGS w_str_c(WIN  *,char  *);
int FIXED_NO_ARGS w_str(WIN  *,int,int,char  *);
#define w_str_a_c	w_str_c_a
int FIXED_NO_ARGS w_str_c_a(WIN  *,char  *,int);
int FIXED_NO_ARGS w_str_a(WIN  *,int,int,char  *,int);
int FIXED_NO_ARGS w_str_col(WIN  *,char  *);
#endif
